@@ -28,6 +28,7 @@ class EmploymentContract(BaseModel):
     manager_user: dict = Field(None, alias="manager-user")
     monthly_salary_start_date: date = Field(None, alias="monthly-salary-start-date")
     vacation_entitlements: dict = Field(None, alias="vacation-entitlements")
+    zip_code: str = Field(None, alias="zip-code")
 
 
 class PeUser(BaseModel):
@@ -70,16 +71,15 @@ class PeUser(BaseModel):
         return f"{delta.years} år, {delta.months} mån"
 
     @property
-    def days_to_birthday(self) -> int:
-        return (self.next_birthday - date.today()).days
+    def days_to_birthday(self, from_date=date.today()) -> int:
+        return (self.next_birthday - from_date).days
 
     @property
-    def next_birthday(self) -> date:
-        now = date.today()
-        next_birthday = datetime.strptime(self.contract.ssn.split("-")[0], "%Y%m%d").replace(year=now.year).date()
-        days_remaining = (next_birthday - now).days
+    def next_birthday(self, from_date=date.today()) -> date:
+        next_birthday = datetime.strptime(self.contract.ssn.split("-")[0], "%Y%m%d").replace(year=from_date.year).date()
+        days_remaining = (next_birthday - from_date).days
         if days_remaining < 0:
-            next_birthday = next_birthday.replace(year=now.year + 1)
+            next_birthday = next_birthday.replace(year=from_date.year + 1)
         return next_birthday
 
     @property
@@ -103,6 +103,15 @@ class PeUser(BaseModel):
             return change_date
         return None
 
+    @property
+    def postaladdress(self) -> str:
+        address = f"{self.contract.address2}, {self.contract.zip_code}, {self.contract.state}"
+        return address
+
+    @property
+    def phone_nr(self) -> str:
+        return self.contract.phone
+
     def __str__(self):
         return f"{self.name} ({self.email})"
 
@@ -157,8 +166,12 @@ class PeUser(BaseModel):
 
 if __name__ == "__main__":
     import os
+    from pprint import pprint
 
     credentials = PeCredentials(company_id=os.getenv("COMPANY"), api_access_token=os.getenv("API"))
     PeUser.pe_credentials = credentials
+
     for user in PeUser.all_users():
-        print(user)
+        print()
+        print(user.name)
+        pprint(user.phone_nr)
